<?php

namespace Modules\Pd\Http\Controllers;

use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;

class PendingMachineBreakdownController extends Controller
{
    public function allPendingMachineBreakdown()
    {

        try {

            $query = 'SELECT pd_production_machine_breakdowns.id,
            pd_production_machine_breakdowns.date,
            pd_production_machine_breakdowns.breakdown_time,
            pd_production_machine_breakdowns.status,
            pp_machinery.machinery_id,
            pp_machinery.machinery_name,
            hr_employee_sites.site,
			(SELECT DISTINCT SUM(1) FROM pd_schedule_machinery_plans WHERE pd_schedule_machinery_plans.machinery_id = pp_machinery.machinery_id AND pd_schedule_machinery_plans.product_primary_id = pp_customer_order_plans_data.product_id) AS orders
            FROM pd_production_machine_breakdowns
            INNER JOIN pp_machinery ON pd_production_machine_breakdowns.machinery_id = pp_machinery.machinery_id
            INNER JOIN hr_employee_sites ON pd_production_machine_breakdowns.site_id = hr_employee_sites.site_id
			INNER JOIN pd_schedule_machinery_plans ON pd_production_machine_breakdowns.machinery_id = pd_schedule_machinery_plans.machinery_id
			INNER JOIN pp_customer_order_plans_data ON pd_schedule_machinery_plans.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
			INNER JOIN pp_customer_orders ON pp_customer_order_plans_data.manufacturing_order_no = pp_customer_orders.factory_po_num WHERE pp_customer_orders.order_status = "4" AND pd_production_machine_breakdowns.status = "0"
            GROUP BY pd_production_machine_breakdowns.id ORDER BY pd_production_machine_breakdowns.id DESC';
            $result = DB::select($query);
            $responseBody = $this->responseBody(true, "ReasonOfBreakdownController", "allDailyProduction", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ReasonOfBreakdownController", "error", $exception->getMessage());
        }

        return response()->json(["data" => $responseBody]);
    }



    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
